[pLog-svn] r5083 - plugins/branches/lifetype-1.1/tidyoutput
oscar at devel.lifetype.net
oscar at devel.lifetype.net
Tue Mar 13 14:50:58 EDT 2007
Author: oscar
Date: 2007-03-13 14:50:58 -0400 (Tue, 13 Mar 2007)
New Revision: 5083
Modified:
plugins/branches/lifetype-1.1/tidyoutput/plugintidyoutput.class.php
Log:
Fixed an issue with the authimage plugin, thanks Elena for the update.
Modified: plugins/branches/lifetype-1.1/tidyoutput/plugintidyoutput.class.php
===================================================================
--- plugins/branches/lifetype-1.1/tidyoutput/plugintidyoutput.class.php 2007-03-13 14:44:08 UTC (rev 5082)
+++ plugins/branches/lifetype-1.1/tidyoutput/plugintidyoutput.class.php 2007-03-13 18:50:58 UTC (rev 5083)
@@ -63,8 +63,10 @@
{
if ($eventType == EVENT_PROCESS_BLOG_TEMPLATE_OUTPUT)
{
- // If output is a RSS output do not tidyfy
- if ($params["from"] != "rssview" && $params["from"] != "pluginrecentcommentsrssview")
+ // If output is a RSS output or come from authimageshow call do not tidyfy
+ if ($params["from"] != "rssview" &&
+ $params["from"] != "pluginrecentcommentsrssview" &&
+ $params["template"] != "authimageshow")
{
$params["content"] = $this->tidyfy($params["content"]);
}
More information about the pLog-svn
mailing list